@@ -1,4 +1,4 @@
-aov3 = function(Formula, Data)
+aov3 = function(Formula, Data, BETA=FALSE, Resid=FALSE)
 {
   if (!attr(terms(Formula, data=Data), "response")) {
     stop("Dependent variable should be provided!")
@@ -20,8 +20,30 @@ aov3 = function(Formula, Data)
 
   rx = lfit(x, y)
   Tx = SS(x, rx, Lx)
-
   SST = as.numeric(crossprod(y - attr(x$terms, "intercept")*mean(y)))
+  Res0 = sumANOVA(rx, Tx, SST, nrow(x$X), rownames(attr(terms(x), "factors"))[1])
 
-  return(sumANOVA(rx, Tx, SST, nrow(x$X), rownames(attr(terms(x), "factors"))[1]))
+  if (!BETA & !Resid) {
+    Result = Res0
+  } else {
+    Result = list(ANOVA=Res0)
+    iNext = 2
+
+    if (BETA) {
+      Result[[iNext]] = sumREG(rx, x$X)
+      names(Result)[iNext] = "Parameter"
+      iNext = iNext + 1
+    }
+
+    if (Resid) {
+      yhat = as.numeric(x$X %*% rx$coefficients)
+      Result[[iNext]] = yhat
+      names(Result)[iNext] = "Fitted"
+
+      Result[[iNext + 1]] = y - yhat
+      names(Result)[iNext + 1] = "Residual"
+    }
+  }
+
+  return(Result)
 }
